.. :changelog:

History
-------
0.1.2 (2016-01-27)
++++++++++++++++++

* Added support for sampling with multiple distance simultaneously
* Clean setup.py 
* Simplifying the code
* Improved documentation


0.1.1 (2015-05-03)
++++++++++++++++++

* Python 3 support
* Minor fixes
* Improved documentation

0.1.0 (2015-04-28)
++++++++++++++++++

* First release